==> equinox-0.11.1.tar.gz: equinox-0.11.1/equinox/nn/__init__.py <==
from ._activations import PReLU as PReLU
from ._attention import MultiheadAttention as MultiheadAttention
from ._batch_norm import BatchNorm as BatchNorm
from ._conv import (
    Conv as Conv,
    Conv1d as Conv1d,
    Conv2d as Conv2d,
    Conv3d as Conv3d,
    ConvTranspose as ConvTranspose,
    ConvTranspose1d as ConvTranspose1d,
    ConvTranspose2d as ConvTranspose2d,
    ConvTranspose3d as ConvTranspose3d,
)
from ._dropout import Dropout as Dropout
from ._embedding import Embedding as Embedding
from ._inference import inference_mode as inference_mode
from ._linear import Identity as Identity, Linear as Linear
from ._mlp import MLP as MLP
from ._normalisation import GroupNorm as GroupNorm, LayerNorm as LayerNorm
from ._pool import (
    AdaptiveAvgPool1d as AdaptiveAvgPool1d,
    AdaptiveAvgPool2d as AdaptiveAvgPool2d,
    AdaptiveAvgPool3d as AdaptiveAvgPool3d,
    AdaptiveMaxPool1d as AdaptiveMaxPool1d,
    AdaptiveMaxPool2d as AdaptiveMaxPool2d,
    AdaptiveMaxPool3d as AdaptiveMaxPool3d,
    AdaptivePool as AdaptivePool,
    AvgPool1d as AvgPool1d,
    AvgPool2d as AvgPool2d,
    AvgPool3d as AvgPool3d,
    MaxPool1d as MaxPool1d,
    MaxPool2d as MaxPool2d,
    MaxPool3d as MaxPool3d,
    Pool as Pool,
)
from ._rnn import GRUCell as GRUCell, LSTMCell as LSTMCell
from ._sequential import (
    Lambda as Lambda,
    Sequential as Sequential,
    StatefulLayer as StatefulLayer,
)
from ._shared import Shared as Shared
from ._spectral_norm import SpectralNorm as SpectralNorm
from ._stateful import (
    delete_init_state as delete_init_state,
    make_with_state as make_with_state,
    State as State,
    StateIndex as StateIndex,
)

==> equinox-0.11.7.tar.gz: equinox-0.11.7/equinox/nn/__init__.py <==
from ._activations import PReLU as PReLU
from ._attention import MultiheadAttention as MultiheadAttention
from ._batch_norm import BatchNorm as BatchNorm
from ._conv import (
    Conv as Conv,
    Conv1d as Conv1d,
    Conv2d as Conv2d,
    Conv3d as Conv3d,
    ConvTranspose as ConvTranspose,
    ConvTranspose1d as ConvTranspose1d,
    ConvTranspose2d as ConvTranspose2d,
    ConvTranspose3d as ConvTranspose3d,
)
from ._dropout import Dropout as Dropout
from ._embedding import (
    Embedding as Embedding,
    RotaryPositionalEmbedding as RotaryPositionalEmbedding,
)
from ._inference import inference_mode as inference_mode
from ._linear import Identity as Identity, Linear as Linear
from ._mlp import MLP as MLP
from ._normalisation import (
    GroupNorm as GroupNorm,
    LayerNorm as LayerNorm,
    RMSNorm as RMSNorm,
)
from ._pool import (
    AdaptiveAvgPool1d as AdaptiveAvgPool1d,
    AdaptiveAvgPool2d as AdaptiveAvgPool2d,
    AdaptiveAvgPool3d as AdaptiveAvgPool3d,
    AdaptiveMaxPool1d as AdaptiveMaxPool1d,
    AdaptiveMaxPool2d as AdaptiveMaxPool2d,
    AdaptiveMaxPool3d as AdaptiveMaxPool3d,
    AdaptivePool as AdaptivePool,
    AvgPool1d as AvgPool1d,
    AvgPool2d as AvgPool2d,
    AvgPool3d as AvgPool3d,
    MaxPool1d as MaxPool1d,
    MaxPool2d as MaxPool2d,
    MaxPool3d as MaxPool3d,
    Pool as Pool,
)
from ._rnn import GRUCell as GRUCell, LSTMCell as LSTMCell
from ._sequential import (
    Lambda as Lambda,
    Sequential as Sequential,
    StatefulLayer as StatefulLayer,
)
from ._shared import Shared as Shared
from ._spectral_norm import SpectralNorm as SpectralNorm
from ._stateful import (
    delete_init_state as delete_init_state,
    make_with_state as make_with_state,
    State as State,
    StateIndex as StateIndex,
)
from ._weight_norm import WeightNorm as WeightNorm
